==> com.liferay.document.library.repository.cmis.impl-3.0.13-sources.jar: com/liferay/document/library/repository/cmis/internal/constants/CMISRepositoryConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.document.library.repository.cmis.internal.constants;

/**
 * @author Adolfo Pérez
 */
public class CMISRepositoryConstants {

	public static final String CMIS_ATOMPUB_CONFIGURATION = "ATOMPUB";

	public static final String CMIS_ATOMPUB_REPOSITORY_CLASSNAME =
		"com.liferay.document.library.repository.cmis.internal." +
			"CMISAtomPubRepository";

	public static final String CMIS_ATOMPUB_REPOSITORY_ID_PARAMETER =
		"REPOSITORY_ID";

	public static final String CMIS_ATOMPUB_URL_PARAMETER = "ATOMPUB_URL";

	public static final String CMIS_WEB_SERVICES_REPOSITORY_CLASSNAME =
		"com.liferay.document.library.repository.cmis.internal." +
			"CMISWebServicesRepository";

	public static final String CMIS_WEBSERVICES_ACL_SERVICE_PARAMETER =
		"WEBSERVICES_ACL_SERVICE";

	public static final String CMIS_WEBSERVICES_CONFIGURATION = "WEBSERVICES";

	public static final String CMIS_WEBSERVICES_DISCOVERY_SERVICE_PARAMETER =
		"WEBSERVICES_DISCOVERY_SERVICE";

	public static final String CMIS_WEBSERVICES_MULTIFILING_SERVICE_PARAMETER =
		"WEBSERVICES_MULTIFILING_SERVICE";

	public static final String CMIS_WEBSERVICES_NAVIGATION_SERVICE_PARAMETER =
		"WEBSERVICES_NAVIGATION_SERVICE";

	public static final String CMIS_WEBSERVICES_OBJECT_SERVICE_PARAMETER =
		"WEBSERVICES_OBJECT_SERVICE";

	public static final String CMIS_WEBSERVICES_POLICY_SERVICE_PARAMETER =
		"WEBSERVICES_POLICY_SERVICE";

	public static final String CMIS_WEBSERVICES_RELATIONSHIP_SERVICE_PARAMETER =
		"WEBSERVICES_RELATIONSHIP_SERVICE";

	public static final String CMIS_WEBSERVICES_REPOSITORY_ID_PARAMETER =
		"REPOSITORY_ID";

	public static final String CMIS_WEBSERVICES_REPOSITORY_SERVICE_PARAMETER =
		"WEBSERVICES_REPOSITORY_SERVICE";

	public static final String CMIS_WEBSERVICES_VERSIONING_SERVICE_PARAMETER =
		"WEBSERVICES_VERSIONING_SERVICE";

}

==> com.liferay.document.library.repository.cmis.impl-6.0.20-sources.jar: com/liferay/document/library/repository/cmis/internal/constants/CMISRepositoryConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.document.library.repository.cmis.internal.constants;

/**
 * @author Adolfo Pérez
 */
public class CMISRepositoryConstants {

	public static final String CMIS_ATOMPUB_CONFIGURATION = "ATOMPUB";

	public static final String CMIS_ATOMPUB_REPOSITORY_CLASS_NAME =
		"com.liferay.document.library.repository.cmis.internal." +
			"CMISAtomPubRepository";

	public static final String CMIS_ATOMPUB_REPOSITORY_ID_PARAMETER =
		"REPOSITORY_ID";

	public static final String CMIS_ATOMPUB_URL_PARAMETER = "ATOMPUB_URL";

	public static final String CMIS_WEB_SERVICES_REPOSITORY_CLASS_NAME =
		"com.liferay.document.library.repository.cmis.internal." +
			"CMISWebServicesRepository";

	public static final String CMIS_WEBSERVICES_ACL_SERVICE_PARAMETER =
		"WEBSERVICES_ACL_SERVICE";

	public static final String CMIS_WEBSERVICES_CONFIGURATION = "WEBSERVICES";

	public static final String CMIS_WEBSERVICES_DISCOVERY_SERVICE_PARAMETER =
		"WEBSERVICES_DISCOVERY_SERVICE";

	public static final String CMIS_WEBSERVICES_MULTIFILING_SERVICE_PARAMETER =
		"WEBSERVICES_MULTIFILING_SERVICE";

	public static final String CMIS_WEBSERVICES_NAVIGATION_SERVICE_PARAMETER =
		"WEBSERVICES_NAVIGATION_SERVICE";

	public static final String CMIS_WEBSERVICES_OBJECT_SERVICE_PARAMETER =
		"WEBSERVICES_OBJECT_SERVICE";

	public static final String CMIS_WEBSERVICES_POLICY_SERVICE_PARAMETER =
		"WEBSERVICES_POLICY_SERVICE";

	public static final String CMIS_WEBSERVICES_RELATIONSHIP_SERVICE_PARAMETER =
		"WEBSERVICES_RELATIONSHIP_SERVICE";

	public static final String CMIS_WEBSERVICES_REPOSITORY_ID_PARAMETER =
		"REPOSITORY_ID";

	public static final String CMIS_WEBSERVICES_REPOSITORY_SERVICE_PARAMETER =
		"WEBSERVICES_REPOSITORY_SERVICE";

	public static final String CMIS_WEBSERVICES_VERSIONING_SERVICE_PARAMETER =
		"WEBSERVICES_VERSIONING_SERVICE";

}
